pub struct HistoryEntry {
pub id: usize,
pub hash: String,
pub subject: String,
pub operation: String,
pub target: String,
pub files: Vec<String>,
pub message: Option<String>,
pub workflow: Option<String>,
pub git_head: String,
pub timestamp: String,
}Expand description
A single entry in shadow git history.
Fields
id: usizehash: Stringsubject: Stringoperation: Stringtarget: Stringfiles: Vec<String>message: Option<String>workflow: Option<String>git_head: Stringtimestamp: StringTrait Implementations
Sourceimpl Clone for HistoryEntry
impl Clone for HistoryEntry
Sourcefn clone(&self) -> HistoryEntry
fn clone(&self) -> HistoryEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HistoryEntry
impl Debug for HistoryEntry
Sourceimpl JsonSchema for HistoryEntry
impl JsonSchema for HistoryEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HistoryEntry
impl RefUnwindSafe for HistoryEntry
impl Send for HistoryEntry
impl Sync for HistoryEntry
impl Unpin for HistoryEntry
impl UnsafeUnpin for HistoryEntry
impl UnwindSafe for HistoryEntry