Shadow Git - automatic edit history tracking.
Maintains a hidden git repository (.normalize/shadow/) that automatically
commits after each normalize edit operation, preserving full edit history.
Structs
- Edit
Info - Information about an edit operation for shadow commit.
- History
Entry - A single entry in shadow git history.
- Shadow
- Shadow git repository manager.
- Shadow
Config - Shadow git configuration.
- Undo
Result - Result of an undo operation.
- Validation
Result - Result of running a validation command in shadow worktree.
Enums
- Shadow
Error - Shadow git errors.